==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebPivotGridValueTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotValueDescriptionMetadata } from "./WebPivotValueDescriptionMetadata";
import { WebPivotGridValueTemplateContextDescription } from "./WebPivotGridValueTemplateContextDescription";
/**
 * @hidden
 */
var WebPivotGridValueTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotGridValueTemplateContextDescriptionMetadata, _super);
    function WebPivotGridValueTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotGridValueTemplateContextDescriptionMetadata.b = function (a) {
        if (WebPivotGridValueTemplateContextDescriptionMetadata.a == null) {
            WebPivotGridValueTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotGridValueTemplateContextDescriptionMetadata.c(WebPivotGridValueTemplateContextDescriptionMetadata.a);
        }
        if (a.j(WebPivotGridValueTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPivotGridValueTemplateContextDescriptionMetadata.a);
        WebPivotValueDescriptionMetadata.d(a);
    };
    WebPivotGridValueTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotGridValueTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("Implicit", "ExportedType:WebPivotValue");
    };
    WebPivotGridValueTemplateContextDescriptionMetadata.d = function (a) {
        WebPivotGridValueTemplateContextDescriptionMetadata.b(a);
        a.aa("WebPivotGridValueTemplateContext", function () { return new WebPivotGridValueTemplateContextDescription(); });
        a.z("WebPivotGridValueTemplateContext", WebPivotGridValueTemplateContextDescriptionMetadata.a);
    };
    WebPivotGridValueTemplateContextDescriptionMetadata.$t = markType(WebPivotGridValueTemplateContextDescriptionMetadata, 'WebPivotGridValueTemplateContextDescriptionMetadata');
    WebPivotGridValueTemplateContextDescriptionMetadata.a = null;
    return WebPivotGridValueTemplateContextDescriptionMetadata;
}(Base));
export { WebPivotGridValueTemplateContextDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebPivotGridValueTemplateContextDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPivotValueDescriptionMetadata } from "./WebPivotValueDescriptionMetadata";
import { WebPivotGridValueTemplateContextDescription } from "./WebPivotGridValueTemplateContextDescription";
/**
 * @hidden
 */
var WebPivotGridValueTemplateContextDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebPivotGridValueTemplateContextDescriptionMetadata, _super);
    function WebPivotGridValueTemplateContextDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPivotGridValueTemplateContextDescriptionMetadata.b = function (a) {
        if (WebPivotGridValueTemplateContextDescriptionMetadata.a == null) {
            WebPivotGridValueTemplateContextDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPivotGridValueTemplateContextDescriptionMetadata.c(WebPivotGridValueTemplateContextDescriptionMetadata.a);
        }
        if (a.k(WebPivotGridValueTemplateContextDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPivotGridValueTemplateContextDescriptionMetadata.a);
        WebPivotValueDescriptionMetadata.d(a);
    };
    WebPivotGridValueTemplateContextDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PivotGridValueTemplateContext");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Implicit", "ExportedType:WebPivotValue");
    };
    WebPivotGridValueTemplateContextDescriptionMetadata.d = function (a) {
        WebPivotGridValueTemplateContextDescriptionMetadata.b(a);
        a.ac("WebPivotGridValueTemplateContext", function () { return new WebPivotGridValueTemplateContextDescription(); });
        a.ab("WebPivotGridValueTemplateContext", WebPivotGridValueTemplateContextDescriptionMetadata.a);
    };
    WebPivotGridValueTemplateContextDescriptionMetadata.$t = markType(WebPivotGridValueTemplateContextDescriptionMetadata, 'WebPivotGridValueTemplateContextDescriptionMetadata');
    WebPivotGridValueTemplateContextDescriptionMetadata.a = null;
    return WebPivotGridValueTemplateContextDescriptionMetadata;
}(Base));
export { WebPivotGridValueTemplateContextDescriptionMetadata };
